======
Identeco
======

Identeco is a Django application that provides an OpenID 2.0 compatible OpenID
provider.

Development
-----------

The source repository can be found at https://github.com/eldarion/identeco/


Contents
========

.. toctree::
 :maxdepth: 1

 changelog
 installation
 templatetags

